@@ -13,6 +13,7 @@ from decimal import Decimal
 from functools import partial
 from typing import Union
 
+from .dict_to_dataclass import get_dataclass_field_name_to_field
 
 Jsonable = Union[list, dict, str, int, float, None]
 
@@ -36,7 +37,7 @@ class EnhancedJSONEncoder(json.JSONEncoder):
         if is_dataclass(o):
             # d = asdict(o)
             d = {}
-            dataclass_fields = o.__dataclass_fields__
+            dataclass_fields = get_dataclass_field_name_to_field(type(o), with_init_vars=False)
             for key in dataclass_fields:
                 descriptor: Field = dataclass_fields[key]
                 if descriptor.repr:
