@@ -12,19 +12,15 @@ import functools
 import itertools
 import json
 import types
-from typing import Any, TypeVar, Union, Callable, Optional, Protocol, ClassVar, Dict
+from typing import Any, TypeVar, Union, Callable, Optional
 
 from .is_instance import get_container_type, is_instance
 from .str_to_bool import to_bool
 
 
-class IsDataclass(Protocol):
-    __dataclass_fields__: ClassVar[Dict]
-
-
 @functools.cache
 def get_dataclass_field_name_to_field(
-        dataclass_: IsDataclass,
+        dataclass_: Any,
         with_init_vars: bool = True, with_class_vars: bool = False
 ) -> dict[str, dataclasses.Field]:
     try:
